==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm5/lib/Stacked100LineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StackedLineSeries } from "./StackedLineSeries";
import { IStacked100Series_$type } from "./IStacked100Series";
import { markType } from "igniteui-react-core";
import { Stacked100DataPreparer } from "./Stacked100DataPreparer";
import { StackedLineSeriesView } from "./StackedLineSeriesView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var Stacked100LineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100LineSeries, _super);
    function Stacked100LineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = Stacked100LineSeries.$;
        return _this;
    }
    Stacked100LineSeries.prototype.cg = function () {
        return new Stacked100LineSeriesView(this);
    };
    Stacked100LineSeries.prototype.o0 = function (a) {
        _super.prototype.o0.call(this, a);
        this.yl = a;
    };
    Stacked100LineSeries.prototype.get_xn = function () {
        return true;
    };
    Stacked100LineSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.pp(false);
    };
    Stacked100LineSeries.prototype.x3 = function () {
        _super.prototype.x3.call(this);
        Stacked100DataPreparer.a(this);
    };
    Object.defineProperty(Stacked100LineSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.wi;
        },
        enumerable: false,
        configurable: true
    });
    Stacked100LineSeries.$t = markType(Stacked100LineSeries, 'Stacked100LineSeries', StackedLineSeries.$, [IStacked100Series_$type]);
    return Stacked100LineSeries;
}(StackedLineSeries));
export { Stacked100LineSeries };
/**
 * @hidden
 */
var Stacked100LineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100LineSeriesView, _super);
    function Stacked100LineSeriesView(a) {
        return _super.call(this, a) || this;
    }
    Stacked100LineSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.c3.ua = Defaults.e;
        }
    };
    Stacked100LineSeriesView.$t = markType(Stacked100LineSeriesView, 'Stacked100LineSeriesView', StackedLineSeriesView.$);
    return Stacked100LineSeriesView;
}(StackedLineSeriesView));
export { Stacked100LineSeriesView };

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/Stacked100LineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StackedLineSeries } from "./StackedLineSeries";
import { IStacked100Series_$type } from "./IStacked100Series";
import { markType } from "igniteui-react-core";
import { Stacked100DataPreparer } from "./Stacked100DataPreparer";
import { StackedLineSeriesView } from "./StackedLineSeriesView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var Stacked100LineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100LineSeries, _super);
    function Stacked100LineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = Stacked100LineSeries.$;
        return _this;
    }
    Stacked100LineSeries.prototype.cr = function () {
        return new Stacked100LineSeriesView(this);
    };
    Stacked100LineSeries.prototype.qz = function (a) {
        _super.prototype.qz.call(this, a);
        this.aby = a;
    };
    Stacked100LineSeries.prototype.get_aaz = function () {
        return true;
    };
    Stacked100LineSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.rp(false);
    };
    Stacked100LineSeries.prototype.abg = function () {
        _super.prototype.abg.call(this);
        Stacked100DataPreparer.a(this);
    };
    Stacked100LineSeries.prototype.aa5 = function (a, b) {
        var c = 0;
        for (var d = 0; d < this.series.count; d++) {
            c += this.series._inner[d].ak.item(b);
        }
        return (this.series._inner[a].ak.item(b) / c) * 100;
    };
    Object.defineProperty(Stacked100LineSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.zl;
        },
        enumerable: false,
        configurable: true
    });
    Stacked100LineSeries.$t = markType(Stacked100LineSeries, 'Stacked100LineSeries', StackedLineSeries.$, [IStacked100Series_$type]);
    return Stacked100LineSeries;
}(StackedLineSeries));
export { Stacked100LineSeries };
/**
 * @hidden
 */
var Stacked100LineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100LineSeriesView, _super);
    function Stacked100LineSeriesView(a) {
        return _super.call(this, a) || this;
    }
    Stacked100LineSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.c5.w5 = Defaults.e;
        }
    };
    Stacked100LineSeriesView.$t = markType(Stacked100LineSeriesView, 'Stacked100LineSeriesView', StackedLineSeriesView.$);
    return Stacked100LineSeriesView;
}(StackedLineSeriesView));
export { Stacked100LineSeriesView };
